from setuptools import setup

setup(name = 'probability_dists_ds',
      version = '0.1',
      description = 'Gaussian and Binomial Probability Distributions',
      packages = ['probability_dists_ds'],
      author = "Sunil Raut Kshetri",
      author_email = "myemail@something.com",
      zip_safe = False)
